SVN: ZODB/branches/tseaver-repozo_index/src/ZODB/scripts/repozo.py Update docstring to note index save / restore, and stdout exception.

Tres Seaver <[email protected]>
Newsgroups gmane.comp.python.zope.zodb.cvs
Message-ID <[email protected]>
Log message for revision 112340:
  Update docstring to note index save / restore, and stdout exception.

Changed:
  U   ZODB/branches/tseaver-repozo_index/src/ZODB/scripts/repozo.py

-=-
Modified: ZODB/branches/tseaver-repozo_index/src/ZODB/scripts/repozo.py
===================================================================
--- ZODB/branches/tseaver-repozo_index/src/ZODB/scripts/repozo.py	2010-05-15 17:15:09 UTC (rev 112339)
+++ ZODB/branches/tseaver-repozo_index/src/ZODB/scripts/repozo.py	2010-05-15 17:18:15 UTC (rev 112340)
@@ -5,7 +5,7 @@
 # Originally written by Anthony Baxter
 # Significantly modified by Barry Warsaw
 
 """repozo.py -- incremental and full backups of a Data.fs file.
 
 Usage: %(program)s [options]
 Where:
@@ -66,6 +66,9 @@
     --output=filename
         Write recovered ZODB to given file.  By default, the file is
         written to stdout.
+        
+        Note:  for the stdout case, the index file will **not** be restored
+        automatically.
 """
 
 import os
@@ -5,7 +5,7 @@
 # Significantly modified by Barry Warsaw
 
-"""repozo.py -- incremental and full backups of a Data.fs file.
+"""repozo.py -- incremental and full backups of a Data.fs file and index.
 
 Usage: %(program)s [options]
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.